%define _hardened_build 1

%bcond_with enable_caps
%bcond_without libcap

%if %{with libcap}
BuildRequires:  libcap libcap-devel
%define cap_args -DCAPABILITIES=1 -lcap
%define man_args -a libcap=1
%else
%define cap_args %{nil}
%define man_args %{nil}
%endif

Name:		fermilab-util_kcron
Version:	1.0
Release:	0%{?dist}
Summary:	A utility for getting Kerberos credentials in scheduled jobs
Packager:	Fermilab Authentication Services

Group:		Fermilab
License:	MIT
URL:		http://helpdesk.fnal.gov/

SOURCE0:	kcron.doc
SOURCE1:	init-kcron-keytab.c
SOURCE2:	remove-kcron-keytab.c
SOURCE3:	kcron
SOURCE4:	kcrondestroy
SOURCE5:	kcroninit
SOURCE6:        make-cron-keytab

BuildArch:	x86_64

# for actual build
BuildRequires:  gcc coreutils glibc-devel asciidoc

%if 0%{?rhel} < 8
BuildRequires:  devtoolset-6-toolchain devtoolset-6-libasan-devel devtoolset-6-libubsan-devel
%else
BuildRequires: libubsan libubsan-devel libasan libasan-devel
%endif

# for check
BuildRequires:	bash

%if %{_hardened_build}
BuildRequires: hardening-check
%endif

Requires:	krb5-workstation krb5-libs
Requires:	util-linux policycoreutils
Requires(pre):	policycoreutils

Provides:	kcron

%description
The kcron utility has a long history at Fermilab.  It is useful
for running automatic jobs with kerberos rights.

%prep
cp %{SOURCE0} .


%build

%if 0%{?rhel} < 8
%define extra_gcc_options -O3 -fstack-check -finline-functions -fsanitize=address -Wl,-z,noexecstack -Wl,-z,nodump -Wconversion -Wformat-security -Werror -Wextra -Wpedantic -fsanitize=undefined -fno-sanitize-recover -static-libasan -static-libubsan
%else
%define extra_gcc_options -O3 -fstack-check -finline-functions -fsanitize=address -Wl,-z,noexecstack -Wl,-z,nodump -Wconversion -Wformat-security -Werror -Wextra -Wpedantic -fsanitize=undefined -fno-sanitize-recover
%endif

%if 0%{?rhel} < 8
scl enable devtoolset-6 - << \EOF
set -x
%endif

%{__cc} %{optflags} %{__global_ldflags} %{extra_gcc_options} %{cap_args} %{SOURCE1} -o init-kcron-keytab
%{__cc} %{optflags} %{__global_ldflags} %{extra_gcc_options} %{cap_args} %{SOURCE2} -o remove-kcron-keytab

%if 0%{?rhel} < 8
EOF
%endif

asciidoc %{man_args} --backend docbook -a "a2x-format=manpage"  --doctype manpage  --out-file  kcron.xml kcron.doc
a2x --doctype manpage --format manpage  kcron.xml

%install
rm -rf %{buildroot}
%{__install} -d %{buildroot}/%{_bindir}
%{__install} -D init-kcron-keytab %{buildroot}/%{_libexecdir}/kcron/init-kcron-keytab
%{__install} -D remove-kcron-keytab %{buildroot}/%{_libexecdir}/kcron/remove-kcron-keytab
%{__install} %{SOURCE3} %{buildroot}/%{_bindir}/
%{__install} %{SOURCE4} %{buildroot}/%{_bindir}/
%{__install} %{SOURCE5} %{buildroot}/%{_bindir}/
%{__install} %{SOURCE6} %{buildroot}/%{_bindir}/

%{__mkdir_p} %{buildroot}%{_mandir}/man1/
%{__cp} *.1 %{buildroot}%{_mandir}/man1/

%{__mkdir_p} %{buildroot}%{_localstatedir}/adm/krb5

%clean
rm -rf %{buildroot}

%check
for code in $(ls %{buildroot}%{_bindir}); do
    bash -n %{buildroot}%{_bindir}/${code}
    if [[ $? -ne 0 ]]; then
      exit 1
    fi
done

%if %{_hardened_build}
for code in $(ls %{buildroot}%{_libexecdir}/kcron); do
    hardening-check %{buildroot}%{_libexecdir}/kcron/${code}
    if [[ $? -ne 0 ]]; then
      exit 1
    fi
done
%endif

%pre -p /bin/bash
semanage fcontext -a -t user_cron_spool_t '/var/adm/krb5(/.*)?' >/dev/null 2>&1
exit 0


%files
%defattr(0644,root,root,0755)
%attr(0755,root,root) %{_bindir}/*
%doc %{_mandir}/man1/*
%dir %attr(1711,root,users) %{_localstatedir}/adm/krb5

%if %{with enable_caps}
%attr(0755,root,root) %caps(cap_chown=pe cap_fowner=pe cap_dac_override=pe) %{_libexecdir}/kcron/init-kcron-keytab
%attr(0755,root,root) %caps(cap_fowner=pe cap_dac_override=pe) %{_libexecdir}/kcron/remove-kcron-keytab
%else
%if %{with libcap}
%attr(0755,root,root) %caps(cap_chown=p cap_fowner=p cap_dac_override=p) %{_libexecdir}/kcron/init-kcron-keytab
%attr(0755,root,root) %caps(cap_fowner=p cap_dac_override=p) %{_libexecdir}/kcron/remove-kcron-keytab
%else
%attr(4755,root,root) %{_libexecdir}/kcron/init-kcron-keytab
%attr(4755,root,root) %{_libexecdir}/kcron/remove-kcron-keytab
%endif
%endif

%changelog
* Tue May 9 2017 Olga Terlyga <terlyga@fnal.gov> 1.0-1
- Updated for EL7

